@@ -26,10 +26,9 @@ if (getRversion() >= "2.15.1") {
 #' intended as a miscellany of string manipulation functions which cannot be
 #' found in `stringi` or `stringr`.
 #'
-#' @docType package
 #' @name strex
 #' @aliases strex-package
 #' @references Rory Nolan and Sergi Padilla-Parra (2017). filesstrings: An R
 #'   package for file and string manipulation. The Journal of Open Source
 #'   Software, 2(14).  \doi{10.21105/joss.00260}.
-NULL
+"_PACKAGE"
